{% extends "admin/base_site.html" %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{{ _('Home') }}</a></div>{% endblock %}

{% block content %}

<p>{{ _("Thanks for spending some quality time with the Web site today.") }}</p>

<p><a href="../">{{ _('Log in again') }}</a></p>

{% endblock %}