{% load 'adminmedia' %}
{% extends "admin/base.html" %}

{% block title %}{{ title }} | {{ _('Django site admin') }}{% endblock %}
{% block branding %}
<h1 id="site-name">
{{ _('Django administration') }}</h1>
{% endblock %}

{% block navglobal %}{% endblock %}
