{% extends "admin/base_site.html" %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{{ _('Home') }}</a> &rsaquo; {{ _('Password reset') }}</div>{% endblock %}

{% block title %}{{ _("Password reset") }}{% endblock %}

{% block content %}

<h1>{{ _("Password reset") }}</h1>

<p>{{ _("Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." ) }}</p>

<form action="" method="post">{% csrf_token %}
{{ form.email.errors }}
<p><label for="id_email">{{ _('E-mail address:') }}</label> {{ form.email }} <input type="submit" value="{{ _('Reset my password') }}" /></p>
</form>

{% endblock %}