<div class="djDebugPanelTitle">
	<a class="djDebugClose djDebugBack" href="">{{ _("Back") }}</a>
	<h3>{{ _("SQL Profiled") }}</h3>
</div>
<div class="djDebugPanelContent">
	<div class="scroll">
		{% if result %}
			<dl>
				<dt>{{ _("Executed SQL") }}</dt>
				<dd>{{ sql|safe }}</dd>
				<dt>{{ _("Time") }}</dt>
				<dd>{{ duration }} ms</dd>
			</dl>
			<table class="djSqlProfile">
				<thead>
					<tr>
						{% for h in headers %}
							<th>{{ h|upper }}</th>
						{% endfor %}
					</tr>
				</thead>
				<tbody>
					{% for row in result %}
						<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
							{% for column in row %}
								<td>{{ column|escape }}</td>
							{% endfor %}
						</tr>
					{% endfor %}
				</tbody>
			</table>
		{% else %}
			<dl>
				<dt>{{ _('Error') }}</dt>
				<dd>{{ result_error }}</dd>
			</dl>
		{% endif %}
	</div>
</div>