<table>
	<thead>
		<tr>
			<th>{{ _("Package") }}</th>
			<th>{{ _("Version") }}</th>
		</tr>
	</thead>
	<tbody>
		{% for package, version in versions.iteritems() %}
			<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
				<td>{{ package }}</td>
				<td>{{ version }}</td>
			</tr>
		{% endfor %}
	</tbody>
</table>
