{% extends "admin/base_site.html" %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{{ _('Home') }}</a> &rsaquo; {{ _('Password reset confirmation') }}</div>{% endblock %}

{% block title %}{{ _('Password reset') }}{% endblock %}

{% block content %}

{% if validlink %}

<h1>{{ _('Enter new password') }}</h1>

<p>{{ _("Please enter your new password twice so we can verify you typed it in correctly.") }}</p>

<form action="" method="post">{% csrf_token %}
{{ form.new_password1.errors }}
<p class="aligned wide"><label for="id_new_password1">{{ _('New password:') }}</label>{{ form.new_password1 }}</p>
{{ form.new_password2.errors }}
<p class="aligned wide"><label for="id_new_password2">{{ _('Confirm password:') }}</label>{{ form.new_password2 }}</p>
<p><input type="submit" value="{{ _('Change my password') }}" /></p>
</form>

{% else %}

<h1>{{ _('Password reset unsuccessful') }}</h1>

<p>{{ _("The password reset link was invalid, possibly because it has already been used.  Please request a new password reset.") }}</p>

{% endif %}

{% endblock %}
