{% extends "admin/base_site.html" %}
{% block extrastyle %}{{ super() }}<link rel="stylesheet" type="text/css" href="{{ admin_media_prefix }}css/forms.css" />{% endblock %}
{% block userlinks %}{% set docsroot = url('django-admindocs-docroot') %}{% if docsroot %}<a href="{{ docsroot }}">{{ _('Documentation') }}</a> / {% endif %} {{ _('Change password') }} / <a href="../logout/">{{ _('Log out') }}</a>{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{{ _('Home') }}</a> &rsaquo; {{ _('Password change') }}</div>{% endblock %}

{% block title %}{{ _('Password change') }}{% endblock %}

{% block content %}<div id="content-main">

<form action="" method="post">{% csrf_token %}
<div>
{% if form.errors %}
    <p class="errornote">
    {% trans count=form.errors.items()|length %}Please correct the error below.{% pluralize %}Please correct the errors below.{% endtrans %}
    </p>
{% endif %}

<h1>{{ _('Password change') }}</h1>

<p>{{ _("Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly.") }}</p>

<fieldset class="module aligned wide">

<div class="form-row">
    {{ form.old_password.errors }}
    <label for="id_old_password" class="required">{{ _('Old password') }}:</label>{{ form.old_password }}
</div>

<div class="form-row">
    {{ form.new_password1.errors }}
    <label for="id_new_password1" class="required">{{ _('New password') }}:</label>{{ form.new_password1 }}
</div>

<div class="form-row">
{{ form.new_password2.errors }}
    <label for="id_new_password2" class="required">{{ _('Password (again)') }}:</label>{{ form.new_password2 }}
</div>

</fieldset>

<div class="submit-row">
    <input type="submit" value="{{ _('Change my password') }}" class="default" />
</div>

<script type="text/javascript">document.getElementById("id_old_password").focus();</script>
</div>
</form></div>

{% endblock %}